#
# spec file for package lightspark
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without ffmpeg
%bcond_with    rtmp
Name:           lightspark
Version:        0.8.0+git.20170723
Release:        16.2
Summary:        Flash player implementation
License:        LGPL-3.0+
Group:          Productivity/Multimedia/Other
Url:            https://lightspark.github.io/
Source0:        %{name}-%{version}.tar.xz
Patch0:         lightspark-link.patch
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  hicolor-icon-theme
BuildRequires:  libjpeg-devel
BuildRequires:  llvm-devel >= 2.8
BuildRequires:  nasm
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glibmm-2.4)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libxml++-2.6) >= 2.33.1
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
Recommends:     %{_bindir}/gnash
Recommends:     %{name}-lang
ExclusiveArch:  %{ix86} x86_64
%if 0%{?suse_version} > 1320
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel
%endif
%if %{with librtmp}
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(librtmp)
BuildRequires:  pkgconfig(libssl)
%endif
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
%endif

%description
Lightspark is an Flash player implementation for playing files in SWF
format. Lightspark can run as a web browser plugin or as a standalone
application.

Lightspark supports SWF files written on the newest version of the
ActionScript language, ActionScript 3.0, which was introduced at the
same time as Flash Player 9.

%lang_package

%package plugin
Summary:        NPAPI plugin for lightspark
Group:          Productivity/Multimedia/Other
Requires:       %{name} = %{version}
Enhances:       browser(npapi)
Conflicts:      flash-player
Conflicts:      gnash-browser-plugin

%description plugin
NPAPI plugin for lightspark.

%prep
%setup -q
%patch0 -p1

%build
%cmake \
  -DPLUGIN_DIRECTORY=%{_libdir}/browser-plugins \
  -DPPAPI_PLUGIN_DIRECTORY=%{_libdir}/browser-plugins \
  -DENABLE_LIBAVCODEC=%{?with_ffmpeg:YES}%{!?with_ffmpeg:NO} \
  -DENABLE_RTMP=%{?with_rtmp:YES}%{!?with_rtmp:NO} \
  %ifarch x86_64 || %{ix86}
  -DENABLE_SSE2=true \
  %endif
  -Wno-dev
make %{?_smp_mflags}

%install
%cmake_install
%find_lang %{name}
rm -f %{buildroot}%{_libdir}/%{name}/lib%{name}.so
mv %{buildroot}%{_libdir}/%{name}/* \
  %{buildroot}%{_libdir}/
# Not in hicolor theme (lp#1000840)
rm -rf %{buildroot}%{_datadir}/icons/hicolor/20x20

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%doc COPYING.LESSER ChangeLog
%config(noreplace) %{_sysconfdir}/xdg/lightspark.conf
%attr(0755,root,root) %{_bindir}/lightspark
%attr(0755,root,root) %{_bindir}/tightspark
%{_datadir}/applications/lightspark.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_mandir}/man1/lightspark.1*
%{_libdir}/lib%{name}.so*

%files lang -f %{name}.lang

%files plugin
%{_libdir}/browser-plugins/*.so

%changelog
* Fri Jul 28 2017 mpluskal@suse.com
- Update to version 0.8.0+git.20170723:
  * fix file IO and external call handling in ppapi plugin this avoids several possible deadlocks
  * fix compilation with older ffmpeg versions
  * [flash.media] add stubs for classes SoundMixer and Microphone
  * [flash.text.textengine] add several stub classes and enumerations
  * implement flash.crypto.generateRandomBytes
  * [ABCVm] fix possible crash in coerce
  * [BitmapData] add stub for method "treshold"
  * [DisplayObjectContainer] implement methods "removeChildren" and "getObjectsUnderPoint"
  * [BevelFilter] add several stub properties
  * [flash.geom] add method "setTo" to Rectangle and Point
  * [Sound] handle null urlRequest in constructor
  * [pygil] remove wrong stub classes counting
  * [LocalConnection] partially implement property "domain"
  * [System] add stubs for "pauseForGCIfCollectionImminent" and "gc"
  * [XML] fix namespace for several methods
  * [memorystream] small performance improvements
  * [ASObject] use boost::flat_map instead of std::map as variables map for better performance
  * [ASObject] fix compilation with older boost
  * [ImageDecodingPolicy] fix typo
  * [FFMpegStreamDecoder] fix compilation with ffmpeg 3.0 fixes https://github.com/lightspark/lightspark/issues/281
  * [FFMpegStreamDecoder] really fix compilation with ffmpeg 3.0
  * fix detection of llvm 4.0 fixes https://github.com/lightspark/lightspark/issues/284
  * [RootMovieClip] avoid re-binding classes on every InitFrame
  * improve perfomance by caching the property in callProperty and findPropStrict, if possible
  * reduce the number of dynamic_casts
  * use unsigned integer in loops
  * [SharedObject] add missing incRef
  * [ABCVm] fix callPropertyCache
  * [ABCVm] cache type in multiname
  * [TextField] only request invalidation if really neccessary
  * [ABCVm] remove callPropertyCache, it doesn't work correctly and doesn't really improve perfomance
  * [ABCVm] small speedup for getMultiname()
  * [Class_base] performance improvement for isSubClass()
  * add new builtin string "length"
  * [ASObject] only search in declared variables if multiname doesn't contain the public namespace
  * [Array] switch to flat_map
  * [ABCVm] throw correct errors in checkfilter
  * [Matrix3D] add some method stubs
  * [DisplayObject] add some property stubs
  * switch to using a flat_multimap for variables. namespaces in multinames are not sorted anymore.
  * [Array] fix some corner cases when handling index UINT32_MAX
  * [memorystream] cache the u30/s24 codes before executing a function the first time
  * [TagFactory] don't throw exception if tag is longer as expected (Adobe seems to allow this, too)
  * [ThreadPool] increase number of threads this leads to less stuttering when playing multiple sounds
  * set emulated version to current adobe version
  * [SyntheticFunction] add call to ABCVm::preloadFunction
  * enale building of ppapi plugin by default
  * [ASObject] handle declared properties in JSON stringify
  * [ASObject] more fixes for JSON.stringify
  * [ABCVm] use function pointer array instead of switch in executeFunction
  * [IFunction] fix prototype constructor
  * [Number] add toLocaleString and make several properties not enumerable
  * return exit code 1 if exit was caused by uncaught exception
  * [tests] switch to the github adobe avmplus repository as base for the tamarin test suite
  * [Global] make all builtin classes constant traits
  * [Array] implement insertAt() and removeAt()
  * [Vector] implement insertAt() and removeAt()
  * fix test output
  * rework blacklist for tests not working on adobe (not yet complete)
  * [avmplus] implement System.canonicalizeNumber
  * [SharedObject] add stub method setProperty()
  * remove more dynamic_casts
  * [ArgumentConversion] handle Undefined in toConcrete()
  * [ABCVm] fix sxi1 opcode implementation
  * [Array] small performance improvement in isValidMultiname()
  * [ApplicationDomain/avmplus.Domain] fix DomainMemory handling
  * [SyntheticFunction] fix needsRest()
  * [ASFont] add stub for hasGlyphs()
  * [DisplayObjectContainer] fix deleteLegacyChildAt
  * [avmplusDomain] implement loadBytes()
  * reduce number of AsyncDrawJobs by ensuring a DisplayObject is only rendered once until it changes again
  * [InputThread] add null-checks to results of getMouseTarget
  * [ABCVm] implement opcode hasnext (0x1f)
  * remove more dynamic_casts
  * [SystemState] avoid creating AsyncDrawJob if DisplayObject is unchanged
  * add test to blacklist that doesn't work on Adobe
  * [BitmapData] add stub for method "merge"
  * [ABCVm] remove unneeded argument from abc_function
  * implement alpha support for pngs and images with palette
  * [ABCVm] implement opcode 0x43 (callMethod)
  * [DisplayObject] implement ColorTransform handling
  * implement stroke handling in Shapes
  * introduce class asAtom as wrapper around ASObject This allows operations on primitives without reference counting. TODO: There are only a few builtin methods currently converted to this wrapper, see usage of ASFUNCTION_ATOM vs ASFUNCTION
  * fix warning
  * conversion to asAtom, second part calling of functions is now handled in asAtom to avoid creating of new function objects every time the function is executed
  * conversion to asAtom, third part Vector class uses vector of asAtom as underlying data structure
  * move several #includes from .h to .cpp
  * [CairoTokenRenderer] only draw strokes if necessary
  * set results of arithmetic operations on asAtoms as (U)Integers, if possible
  * [Math] fix several corner cases
  * [variables_map] switch to unordered_map as basic datastructure
  * conversion to asAtom, fourth part - all ASString methods use asAtom - ASFUNCTION_ATOM now has additional parameter "sys"
  * [Array] switch to unordered_map to store array elements
  * rework function calling to only count references if neccessary
  * fix compilation for Windows fixes issues #270 and #288 the npapi/ppapi plugins compile but are not tested
  * fix compilation on older stdlib
  * [Array] use std::vector for small arrays (up to 65536 elements) and unordered_map for large arrays
  * [asAtom] make most methods inline
  * [Vector] fix forEach
  * [multiname] small performance improvements
  * add more subtypes for dynamic casts
  * [ExternalInterface] switch to asAtom
  * [SecurityManager] allow to call https URLs even if the main URL is http
  * fix compilation on windows
  * fix compilation in profiling mode fixes https://github.com/lightspark/lightspark/issues/291
  * make NPAPI plugin windowless
  * fix minGW compilation
  * prepare release 0.8
  * bump version number
  * Now Cmake supports LLVM up to 4.0
  * add several missing tags in describeType
  * [ApplicationDomain] fix hasDefinition/getDefinition
  * Add NullVideoDecoder::switchCodec
  * fix ArgumentConversionAtom
  * don't throw if setting a dynamic variable with not-empty namespace
  * [ASString] fix localeCompare
  * [method_info] switch to asAtom for getConstant/getOptional
  * [Integer] switch to asAtom
  * [asAtom] add support for strings with a stringID, reduces the need to create ASString objects in some cases
  * [pygil] implement detection of setVariableAtomByQName
  * add two tests to blacklist that don't work on Adobe
* Thu Mar  2 2017 jengelh@inai.de
- Update description
* Thu Feb 23 2017 mpluskal@suse.com
- Update to version 0.7.2+git.20170107:
  * [ppapi] implement keyboard and mouse event handling
  * [ppapi] implement downloading of additional files
  * directly include shaders into sourcecode to avoid filesystem access which is not allowed in ppapi sandbox
  * [Config] fix loading config from ppapi plugin ppapi doesn't allow direct filesystem access so we just ignore the errors reported when trying to load config file
  * [ppapi] implement separate file cache for ppapi plugin. Now the ppapi plugin runs in sandboxed mode with some limitations: - It doesn't detect system fonts properly as cairo tries to read fontconfig files which is not allowed from sandbox. - Sound output doesn't work yet, as sdl_audio initialization crashes when done inside sandbox.
  * [FFMpegStreamDecoder] fix possible crash when probing input format
  * [ppapi] implement sound support
  * [SoundChannel] implement volume handling
  * [ppapi] implement font rendering
  * [SoundTransform] initialize volume/pan to default values
- Add _service
- Add lightspark-link.patch
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Thu May 30 2013 mhrusecky@suse.cz
- fixed build with new llvm: llvm-3.3.patch
* Mon May  6 2013 reddwarf@opensuse.org
- Update to 0.7.2
  * Improved image support: alpha in palettes, abbreviated JPEGs
  * Improved embedded font parsing and text positioning
  * Open links in a browser (plugin only)
  * BitmapData improvements
  * Fixed many crashes
- Remove lightspark-0.7.0-no_glu.patch. Applied upstream.
* Thu Dec 27 2012 reddwarf@opensuse.org
- Update to 0.7.1
  * Fixes for YouTube
  * Support keyboard press and release events
  * Support mouse wheel events and other mouse event improvements
  * Support LLVM 3.2
  * Implemented hit testing of DisplayObjects
  * Parse JPEG images embedded in DefineBits tags
  * Parse RGB15 and paletted images in DefineBitsLossless tags
  * Improved XML support
- Remove lightspark-0.7.0-llvm32.patch, applied upstream.
* Fri Nov 30 2012 reddwarf@opensuse.org
- Add lightspark-0.7.0-llvm32.patch to fix build with LLVM 3.2
* Wed Oct 31 2012 reddwarf@opensuse.org
- Update to 0.7.0
  * Support LZMA compressed SWFs [Requires liblzma]
  * Improved BitmapData support
  * Improved ActionScript compatibility
  * Improved virtual machine performance and memory consumption
  * Improved XML support
  * Experimental support for bytecode optimization at runtime
  * Improved ExternalInterface (browser integration) support
  * Improved performance of JPEG loading
  * Support for XMLSocket
  * Completely redesigned and improved masking support
- Take minimum version of pkgconfig(libxml++-2.6) and llvm-devel
  from CMakeLists.txt and specify them in the BuildRequires
- Add pkgconfig(liblzma), pkgconfig(gl) and pkgconfig(zlib) BuildRequires
- Remove pkgconfig(gobject-2.0) BuildRequire
- Add lightspark-0.7.0-no_glu.patch and remove explicit glu dependency
* Fri Sep 21 2012 idonmez@suse.com
- Add explicit glu dependency
* Fri Jun 22 2012 reddwarf@opensuse.org
- Update to 0.6.0.1
  * Enable RTMP support by default, requires librtmp
  * Fixed support for IEventDispatcher implementation pattern
  * Improved serialization robustness
  * Improved matrix handling
  * Implement string and namespace pooling to reduce memory consumption
  * Proper support for private namespaces
  * Improved support for fonts
  * Support LLVM 3.1
  * Fix full volume issue when PulseAudio flat volumes are enabled
  * Initial support for AIR desktop applications
  * Support for www.bbc.co.uk video player
- Remove lightspark-0.5.7-llvm_31.patch and
  lightspark-0.5.7-ffmpeg_011.patch, applied upstream
- Optionally support RTMP
* Wed Jun  6 2012 reddwarf@opensuse.org
- Fix ffmpeg 0.11 patch, now upstreamed
* Mon May 28 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11
* Thu May 17 2012 reddwarf@opensuse.org
- Update to 0.5.7
* Tue Mar 27 2012 reddwarf@opensuse.org
- Don't remove rpath
* Thu Mar 22 2012 reddwarf@opensuse.org
- Update to 0.5.5
* Sat Dec 11 2010 reddwarf@opensuse.org
- Initial package
